Crate mr_pdf

Crate mr_pdf 

Re-exports

pub use chart::Chart;
pub use chart::ChartType;
pub use layout::flex::RowBuilder;
pub use layout::table::RowBuilder as TableRowBuilder;
pub use layout::table::TableCell;
pub use layout::table::TableBorderStyle;
pub use layout::table::TableBuilder;
pub use layout::box_layout::BoxBuilder;
pub use layout::multiplexed::MultiplexedTable;
pub use layout::multiplexed::TitleStyle;
pub use layout::text::TextBlock;
pub use layout::markdown::MarkdownRenderer;
pub use pdf::crypto::PdfPermissions;

Modules

chart
draw
Module for future drawing primitives. Currently most drawing operations are implemented directly on the Pdf struct.
font
image
layout
pdf
svg

Structs

ImageBase64Builder
ImageBuilder
Metadata
PDF document metadata.
Pdf
The main entry point for PDF generation.
SvgBuilder
Watermark
Configuration for page watermarks.

Enums

Align
Horizontal text alignment.
Color
A color representation in the RGB space.
Orientation
Page orientation.
PageNumberPosition
Position for automatic page numbering.
PaperSize
Preset paper sizes for PDF generation.
Size
Represents the dimension or weight of a layout element.
VAlign
Vertical alignment within a container.

Traits

SizeExt
Extension trait for numbers to provide fluent Size creation.
ToFlex

Functions

flex
Helper to create a flex size.
pct
Helper to create a percentage size.
pt
Helper to create a point size.