Re-exports
pub use chart::Chart;pub use chart::ChartType;pub use layout::flex::RowBuilder;pub use layout::table::RowBuilder as TableRowBuilder;pub use layout::table::TableCell;pub use layout::table::TableBorderStyle;pub use layout::table::TableBuilder;pub use layout::box_layout::BoxBuilder;pub use layout::multiplexed::MultiplexedTable;pub use layout::multiplexed::TitleStyle;pub use layout::text::TextBlock;pub use layout::markdown::MarkdownRenderer;pub use pdf::crypto::PdfPermissions;
Modules
- chart
- draw
- Module for future drawing primitives.
Currently most drawing operations are implemented directly on the
Pdfstruct. - font
- image
- layout
- svg
Structs
- Image
Base64 Builder - Image
Builder - Metadata
- PDF document metadata.
- The main entry point for PDF generation.
- SvgBuilder
- Watermark
- Configuration for page watermarks.
Enums
- Align
- Horizontal text alignment.
- Color
- A color representation in the RGB space.
- Orientation
- Page orientation.
- Page
Number Position - Position for automatic page numbering.
- Paper
Size - Preset paper sizes for PDF generation.
- Size
- Represents the dimension or weight of a layout element.
- VAlign
- Vertical alignment within a container.